## 2024-科技新聞
### iThome
### iThome 快速了解金融上雲鬆綁重點QA
| VIEW MORE »
|  | ### iThome Anthropic AI助理擷取網路歌詞，遭環球音樂等唱片業者控告侵權
| VIEW MORE »
### iThome 桌機版Google.com測試新聞內容
| VIEW MORE »
|  | ### iThome 微軟計畫關閉Windows 11中的NTLM
| VIEW MORE »
### iThome 歐洲央行將於11月邁入數位歐元的準備階段
| VIEW MORE »
|  | ### iThome 駭客刊登假冒為KeePass的Google搜尋廣告
| VIEW MORE »
### iThome LinkedIn裁撤近700名員工，R&D占8成
| VIEW MORE »
|  | ### iThome 新金融上雲潮
| VIEW MORE »
### iThome 【杜絕10大不當配置：軟體供應商篇】從源頭軟體製造商著手，NSA與CISA提出7項準則
| VIEW MORE »
|  | ### iThome 領導者如何耕耘團隊文化
| VIEW MORE »
### iThome 【資安日報】10月17日，駭客假借提供以色列民眾空襲警報應用程式，意圖搜括安卓手機用戶各式資料
| VIEW MORE »
|  | ### iThome Google發表8項無障礙功能，圍繞在地圖、搜尋與拍照
| VIEW MORE »
### iThome 網飛營收成長7.8%，即日起調漲美國、英國及法國費率
| VIEW MORE »
|  | ### iThome Google Cloud提供智財免責防護，讓客戶使用AI服務不用擔心被告
| VIEW MORE »
### iThome 【資安日報】10月20日，駭客利用後門程式框架Meta攻擊東歐國家的石油產業、天然氣公司、國防工業
| VIEW MORE »
|  | ### iThome Martech雙周報第43期：Google Ads將推出No-code第一方數據整合功能，整合後數據可直接應用於Google數位行銷產品線
| VIEW MORE »
### iThome CVE-2023-20198漏洞已讓數千臺思科裝置淪陷
| VIEW MORE »
|  | ### iThome 【資安週報】2023年10月11日到10月13日
| VIEW MORE »
### iThome 【金融上雲實例：富邦金控】以O365先強化全體員工上雲意識，富邦金要靠多雲加速實踐金融百貨願景
| VIEW MORE »
|  | ### iThome 採用232層NAND快閃記憶體，美光推新一代主流NVMe SSD
| VIEW MORE »
### iThome 微軟開源雲端原生應用程式開發平臺Radius
| VIEW MORE »
|  | ### iThome 金融上雲大鬆綁
| VIEW MORE »
### iThome 新光醫院HIS一次全面大換新，大力發展對外應用瞄準微服務
| VIEW MORE »
|  | ### iThome 思科IOS XE零時差漏洞允許駭客取得最高權限
| VIEW MORE »
### iThome 【金融上雲實例：玉山金控】善用雲原生基礎發展混合雲，玉山金上雲優先考量敏捷和韌性
| VIEW MORE »
|  | ### iThome 未來要讓AI接手電商作業面工作！臺灣家樂福公開5年上雲歷程及數位轉型下一步
| VIEW MORE »
### iThome 【資安日報】10月19日，互動式運算平臺Jupyter Notebook遭到鎖定，駭客部署惡意程式，從中挖礦並盜取雲端服務帳密
| VIEW MORE »
|  | ### iThome 針對10月初發生的資料外洩事故，友訊科技提出進一步說明
| VIEW MORE »
### iThome 金管會正式發布金融業運用AI原則，放寬業者使用AI皆須人為判斷的一致性規範
| VIEW MORE »
|  | ### iThome 史丹佛大學發表基礎模型透明度指標，Llama 2以54%居冠
| VIEW MORE »
### iThome Amazon明年要在英國與義大利部署無人機送貨服務
| VIEW MORE »
|  | ### iThome 印度、微軟及Amazon攜手破獲技術支援詐騙活動
| VIEW MORE »
### iThome 金融上雲再次大鬆綁，將掀起金融業新一波加速上雲潮
| VIEW MORE »
|  | ### iThome 微軟完成動視暴雪收購案，雲端串流遊戲版權交由Ubisoft
| VIEW MORE »
### iThome 挑戰Arm，高通、Google合作開發穿戴裝置RISC-V晶片
| VIEW MORE »
|  | ### iThome 金融上雲有哪些選擇？盤點4大公雲發展重點
| VIEW MORE »
### iThome 桃園市與電信業者合作以網路切片打造急救5G專網，讓救護車到院前可先將患者生理數據、4K影像傳送至醫院作好急救準備
| VIEW MORE »
|  | ### iThome Windows 11 21H2、Server 2012支援到期，Server版搬上Azure可獲得3年支援
| VIEW MORE »
### iThome 今年全球對太陽能的投資將首度超越石油
| VIEW MORE »
|  | ### iThome 【資安月報】2023年9月
| VIEW MORE »
### iThome OpenAI正式開放ChatGPT Bing網頁搜尋，公測DALLE-3
| VIEW MORE »
|  | ### iThome 組織如何選擇DevOps轉型切入點
| VIEW MORE »
### iThome 【資安日報】10月16日，Skype用戶注意！駭客利用外洩帳號發送訊息，透過內嵌VBA指令碼的檔案散布惡意程式DarkGate
| VIEW MORE »
|  | ### iThome 【資安日報】10月18日，使用Telegram、AWS、阿里雲的開發人員遭到鎖定，駭客透過PyPI套件發動供應鏈攻擊
| VIEW MORE »
### iThome 如何在手機等行動裝置上執行LLM模型推論？聯發科AI負責人：得先克服三大挑戰
| VIEW MORE »
|  | ### iThome 台新金控揭生成式AI實驗新進展，涵蓋Chatbot、知識管理、程式助理和虛擬客服
| VIEW MORE »
### iThome 台灣大哥大以AI 2.0技術優化智能客服機器人，提高對用戶提問的理解及回答正確率
| VIEW MORE »
|  | ### iThome 支援馬達控制與DSP數位訊號處理，AMD推入門級FPGA運算板
| VIEW MORE »
### iThome 英特爾推第14代Core桌上型處理器，增加核心數，獨立支援Wi-Fi 7與藍牙5.4無線傳輸
| VIEW MORE »
|  | ### iThome 受ChatGPT等AI Chatbot衝擊，Stack Overflow裁員28%
| VIEW MORE »
### iThome Amazon與WhatsApp也開始支援Passkey
| VIEW MORE »
|  | ### iThome OpenSSF開源惡意套件儲存庫，以應對開源軟體供應鏈安全威脅
| VIEW MORE »
### iThome 研究顯示微調LLM會削弱模型安全性
| VIEW MORE »
|  | ### iThome 中俄國家駭客涉嫌濫用WinRAR零時差漏洞
| VIEW MORE »
### iThome 【金融上雲實例：中國信託金控】以混合雲發展整體戰略，中信金先靠私雲練兵再聚焦多雲和私雲整合
| VIEW MORE »
|  | ### iThome 友訊1.2GB產品原始碼、客戶、員工資料在駭客論壇上兜售
| VIEW MORE »
### iThome FCC批准AR與VR裝置使用6GHz頻段
| VIEW MORE »
|  | ### iThome 【因應10大不當配置：藍隊篇】面對常見錯誤配置引發的資安風險，網路防守者有因應之道可參考
| VIEW MORE »
### iThome 【金融上雲實例：國泰金控】以雲原生發展多雲混合雲，國泰金自建轉型平臺加速大規模上雲
| VIEW MORE »
|  | ### iThome 有2%的IT管理帳戶以「admin」作為密碼
| VIEW MORE »
### Business Next
### Business Next 【圖解】TikTok上紅什麼？台、日重旅遊，韓國熱愛舞蹈挑戰，一張圖找出流量密碼
| VIEW MORE »
|  | ### Business Next Netflix廣告版訂戶激增70%，預告其他方案將漲價！Q3財報亮麗背後，歸功2大政策
| VIEW MORE »
### Business Next 蘋果突擊發布新款Apple Pencil、也換上Type-C充電！怎麼挑選？一張表看懂
| VIEW MORE »
|  | ### Business Next 蔣尚義鴻海處女秀！先進封裝如何大吃IOT市場？鴻海車用半導體策略為何？一次解答
| VIEW MORE »
### Business Next 鴻海科技日｜一台Model N，揭開鴻海物流野心！雙策略長首談致勝關鍵：CDMS是什麼？
| VIEW MORE »
|  | ### Business Next 鄧白氏歡慶「台灣中小企業菁英獎」十週年 數據價值決定台灣中小企業發展的前瞻性與未來性
| VIEW MORE »
### Business Next 黃仁勳秀手繪圖，揭密他與鴻海的「AI工廠夢」！攜手劉揚偉驚喜現身科技日
| VIEW MORE »
|  | ### Business Next 【圖解】獨角獸潮結束，換IPO開派對？4張圖看懂全球風險投資趨勢
| VIEW MORE »
### Business Next Apple Card慘虧數十億，高盛想抽身了！為何說合作蘋果是「噩夢」？哪裡出問題？
| VIEW MORE »
|  | ### Business Next 美國運通CEO揭一天作息：親自回覆200封email、工作17小時還能運動！
| VIEW MORE »
### Business Next 鴻海武器CDMS，為何至今只有納智捷買單？劉揚偉能把CDMS推進中國嗎？
| VIEW MORE »
|  | ### Business Next 特斯拉掀價格血戰，毛利率大跌7％！Cybertruck也要來了，但馬斯克先潑冷水？
| VIEW MORE »
### INSIDE
### 一部影視作品出現在螢幕上之前，經歷了漫長的籌備、拍攝、後製⋯⋯等過程，但是你知道要啟動這些環節，那個讓宇宙誕生的瞬間的大爆炸是什麼嗎？答案是「影視開發」。影視開發是指影視作品拍攝前期的準備工作，主要包括選擇題目，這可能是編劇、導演的創意，或是根據市面上的小說或漫畫進行IP改編而來。選定題目後，再與編劇合作將題材文本化，進而形成完整劇本以進行拍攝。 無論原創或改編，開發是一切影視作品的起點。原創內容行之有年，而IP（Intellectual Property）改編在當今影視製作領域中，變得越來越常見而且重要。在某種程度上，IP改編具有商業保障、角色與情節基礎、品牌延伸等優勢。但是，雖然IP改編有
| VIEW MORE »
### INSIDE 電影製片陳璽文從義大利來到臺灣，從孤身做起，到如今的規模，合作過的對象從歐美等到東南亞各國，更復再到韓國與斯洛伐克，「我開始試著從前期就加入故事的發想，找到適合故事的資金，試圖找到它貼近觀眾的方法。義大利學到的創意製片跟當時臺灣認知『製片就只是管錢』，不一樣。」
| VIEW MORE »
|  | ### INSIDE 影視與音樂是最多臺灣人接觸的文化內容領域，不論哪一個年齡層的閱聽率都達八成五以上，那麼臺灣現在有多少人不僅使用影視OTT也使用音樂串流呢？本文將透過《2022年臺灣文化內容消費趨勢調查報告》的數據進一步深入挖掘影音串流重疊使用的核心市場，觀察市場的推移變化！
| VIEW MORE »
### INSIDE 「作為一個紀錄片工作者，我只是很安分地把作品呈現好，從沒想過參展、得獎，或者觀眾從我作品得到什麼。」說出此話時，盧盈良執導的《神人之家》已在那年的臺北電影獎一口氣摘下百萬首獎、最佳紀錄片、剪輯與觀眾票選獎，是實至名歸的大贏家。
| VIEW MORE »
|  | ### INSIDE 針對是否爭取台積電加碼投資高雄，陳其邁說，近日媒體大幅報導，「我現在先不講」，努力做就對了，「不能講太多」。
| VIEW MORE »
### INSIDE 2022年上映的國片《咒》在我國票房表現亮眼，更吸引亞太地區、中東與拉丁美洲觀眾，並進入該地區各國Netflix排行前10數週。拉丁美洲電影市場因文化與地緣關係，好萊塢電影相較其他外國電影具有優勢。但隨網路影音市場發達，亞洲作品開始在當地發酵。國片《咒》的人氣，反映拉丁美洲或許是國片龐大潛在市場。
| VIEW MORE »
|  | ### INSIDE 這些工作者主要居住在中國、俄羅斯，並且向美國或其他國家的企業謊稱他們是遠距自由工作者，每年賺取數百萬美元的薪資，以資助北韓導彈計畫。
| VIEW MORE »
### INSIDE 眾所期待的 2023 TCCF 創意內容大會即將展開，今年共有「INNOVATIONS」、「MARKET」與「PITCHING」三大主題，廣邀國內外業界人士參與，不管在內容展示、趨勢呈現、產業交流等各方面，都準備了最豐富的各種內容，期待在大會中帶來最前瞻的創意、激盪出更多火花。在「INNOVATIONS」這個主題中，又可以分為三大單元，包括「Showcase」、「Talk」和「Industry Event」，這三個單元要呈現什麼？又會帶來哪些驚喜體驗？讓我們一起透過文策院文化科技處李懷瑾處長和策劃團隊叁式的總監曾煒傑（Jay）的分享來感受一下！ 收聽管道如下：Apple Podcast ｜ht
| VIEW MORE »
|  | ### INSIDE 中國職場社群近日有網友爆料稱，AMD 將開始在中國進行裁員，裁員比例可能為 10% 至 15%，將涉及 300 至 450 名的員工，其中 RTG 部門是重災區。
| VIEW MORE »
### INSIDE 分析師預測，2024 年直播電商市場的總規模將達 350 億美元，是 2021 年的三倍多，到 2026 年，直播購物銷售額有望佔整個電子商務銷售份額 20%，更顯示其中直播電商的快速發展。因此越來越多的品牌也開始進行「創作商務」的商機佈局。
| VIEW MORE »
|  | ### INSIDE 官網號稱 Joseon 元首是「King Andrew Lee」，這位韓裔美國企業家創辦了Private Internet Access、Mt. Gox Live，而且還真的擁有李氏朝鮮王朝血統。
| VIEW MORE »
### INSIDE NVIDIA 研究人員指出，透過人工智慧代理執行訓練的效率，遠比人類透過程式撰寫訓練約可快上 80%，並且能讓機器手臂執行效率提升 50%。
| VIEW MORE »
|  | ### INSIDE 從 ChatGPT 點燃熱潮以來，大型語言模型 (LLM) 成為近半年來產業熱門話題，具有廣泛應用、重塑產業樣貌的能力。但是要從何下手切入應用？本文提供一些方向可以思考。
| VIEW MORE »
### INSIDE 近年來，全球各國都在面臨缺人缺工的危機，尤其臺灣更為顯著。為了克服這個問題，太空產業需要向即將畢業的學生招手，並提供實際訓練機會，以吸引更多人才加入這個領域。經濟部產業發展署也推動產學交流，以培養更多太空產業專才。
| VIEW MORE »
|  | ### INSIDE 第三季 3 奈米製程出貨佔晶圓銷售金額的 6%、5 奈米則佔 37%、7 奈米佔 16%，約佔全季晶圓銷售金額的 59%。
| VIEW MORE »
### INSIDE 經過多次延期、重新設計後，特斯拉終於公布 Cybertruck 的正式交車日了....
| VIEW MORE »
|  | ### INSIDE 相信大家都心有戚戚焉，每次碰到這些落落長的要求，心裡就有底，這組密碼防止自己登入的次數將比防止被盜的次數還來得多。
| VIEW MORE »
### INSIDE 本集我們邀請到「知識衛星」的創辦人 Stephen 游弘宇，與我們分享他在十年內創業四次的心路歷程，以及他如何從過去的經驗中學習，進而在短時間內創辦出「知識衛星」線上教育平台。節目中游弘宇分享了他對「完課率」的獨到見解，探討教育平台要如何在市場中走出獨樹一格的品牌形象，最後他向我們分享了三堂他最推薦的線上課程。
| VIEW MORE »
|  | ### INSIDE 有趣的是，美國海軍陸戰隊不把它叫機器狗，而是叫成「機器山羊」（robotic goat），更讓人吃驚的是，從外觀特徵看起來，這台機器山羊非常可能是中國製造。
| VIEW MORE »
### INSIDE 鴻海今天舉行科技日活動，董事長劉揚偉今天表示，中國遲早會開放電動車外包製造市場，台灣布局為配合品牌客戶需求，初步規劃在台設立年產 5 萬至 10 萬輛產能規模。
| VIEW MORE »
|  | ### INSIDE 馬斯克（Elon Musk）在他的 X 平台帳號發文表示：「其中一種費用較低，具備所有功能，但廣告沒減少；另一種費用較貴，但沒有廣告。」
| VIEW MORE »
### INSIDE 若交易完成 OpenAI 估值將超過 800 億美元，並成為舊金山最有價值的新創，也會是全球最具價值的科技新創之一，排在字節跳動和 SpaceX 之後。
| VIEW MORE »
|  | ### INSIDE 美國政府最新限制措施有哪些？本文從晶片納管範圍、小晶片漏洞、輝達的中國挑戰者各方面一次統整。
| VIEW MORE »
### INSIDE 台灣島看似渺小，卻能在經濟社會發展指標名列前茅，例如今年IMD世界競爭力排名全球第６ （其中經濟韌性更創新高到第 5 名）、在人口數兩千萬以上國家，台灣 2022 年人均 GDP 在 191 個經濟體當中排為第 7。能有這樣好成績，不得不提產業/科學園區的設立，扮演驅動台灣經濟發展的重要火車頭。
| VIEW MORE »
|  | ### INSIDE 今年 10 月 17 日，微軟將舉辦免費課程「AI 科普：掌握生成式 AI 的強大力量」，歡迎對最新 AI 發展、未來職場趨勢感興趣的您報名參與，一同理解如何掌握 AI 並了解更多的應用可能。
| VIEW MORE »
### INSIDE 今年 10 月 24 日中小企業開發公司資鼎將攜手關鍵評論網，舉辦「第一島鏈新創英雄會」新創論壇，邀請臺灣重點新創企業家、證交所長官與賴副總統等重量級人物對談，從新創實務與國家發展的角度，深入探討臺灣新創生態系的過去與未來。活動席次有限，立即點擊報名吧！
| VIEW MORE »
|  | ### INSIDE 由連續創業家郭家齊、廖家欣共同創辦的時尚轉售平台 PopChill（拍拍圈科技）宣布完成 Pre-A+ 募資，總共獲得 5700 萬台幣投資額，加上年初的 Pre-A 就有 1.57 億了！
| VIEW MORE »
### INSIDE 中國國家主席習近平宣布全面取消製造業領域的外資准入限制措施，這一舉措顯示了中國對外開放的態度和決心，並有利於推動中國從製造業大國走向製造業強國。
| VIEW MORE »
|  | ### INSIDE 美國太空總署的洞察號探測器在火星偵測到最大的地震，科學家們得出結論，這次地震是由火星地殼活動引起，而不是隕石撞擊。這對於了解火星的地質構造和規劃未來的火星任務至關重要。
| VIEW MORE »
### INSIDE 在挑選家中寬頻網路時，多數人會陷入「對稱頻寬」的迷思認為上傳與下載的速率兩者越高越好，但其實並非如此，根據目前大部分消費者上網習慣來說，反而更應該關注於下載頻寬速度以及Wi-Fi涵蓋率，才能達到最佳的上網體驗！
| VIEW MORE »
|  | ### INSIDE 出版商指出，Claude 聊天機器人未經許可就擅自大量抓取歌詞，製作幾乎相同的複製品，「它會以幾乎逐字複製的歌詞作為回應。」
| VIEW MORE »
### INSIDE 近日黃仁勳出席鴻海科技日備受關注，我們將深入分析黃仁勳與鴻海還有什麼合作的可能性。接著，因為一篇報導讓比特幣價格短時間暴漲又急遽下跌，探討幣圈未來可能的趨勢走向。最後我們討論，Sam Altman 提到 OpenAI 的營收將創下新高峰，這一事件又會如何影響市場趨勢。
| VIEW MORE »
|  | ### INSIDE 不過新的 Airtag 2 會與現在的版本有什麼不一樣？新品應會在精度範圍距離上有所改善。而目前 Airtag 1 的範圍約在 10 至 15 公尺；最新的 iPhone 15 支援的距離則最遠可達 60 公尺。而 Airtag 2 還有可能有「3D 精確定位」（3D Precision Finding）的功能。
| VIEW MORE »
### INSIDE 《A.I.創世者》以其獨特的故事和表達，成功引起了人們對 AI 未來發展的關注和思考。在欣賞這部電影的同時，我們也許能更深入地了解到 AI 帶來的機會與挑戰，而思考的方向更除了對準應用之外，也擴大到如何共處吧！
| VIEW MORE »
|  | ### INSIDE 「叛逆、融入社會失敗，是創作者的特質。」大疫年代，隔著一方窗框，吳曉樂在螢幕彼岸，分享著她的洞察。從著作《你的孩子不是你的孩子》談論升學主義下的親子關係，《上流兒童》道出上流社會的畸形人際，《致命登入》談網路遊戲等，每次出手，總能引領讀者重新思索周身那些因習慣而忽略的框架。這或許可以歸因於創作者的特質，永遠站在社會的岸邊，客觀而清楚地凝視。
| VIEW MORE »
### INSIDE 如果你現在還在愛用「😂」，年輕人可能認為你已經老了！那麼甚麼 emoji 可以取代「笑到哭」的意境呢？
| VIEW MORE »
|  | ### INSIDE 來自美國的郭文泰，原在美國西北大學攻讀博士，以臺灣小劇場為研究對象，1992 年來臺學習國劇後，深受臺灣藝術環境的豐富性吸引，長年遊走於臺美兩地，並在 1998 年創立河床劇團，擔任劇團藝術總監及導演，以「意象劇場」理念堅持為觀眾創造非日常的體驗，創作手法橫跨劇場藝術、身體表演、視覺藝術等領域。
| VIEW MORE »
### INSIDE 貝佐斯的物流大業延伸至外太空。
| VIEW MORE »
|  | ### INSIDE Google 宣布在台灣首次推出 Pixel 產品體驗空間，希望讓更多人能夠進一步感受 Pixel 裝置在整合 Google AI 與多元實用服務下，能夠實現的智慧生活。
| VIEW MORE »
### INSIDE 黃仁勳大讚 Model B 很漂亮，也是年輕夫妻、情侶理想中的用車，但除了幫 Model B 站台以外，這次黃仁勳現身鴻海科技日自然是為了 AI 而來。
| VIEW MORE »
|  | ### INSIDE TikTok 分享在台灣流行的短影音內容類型：美食、旅遊、音樂和搞笑內容，皆各累積了數十億次的觀看數。
| VIEW MORE »
### INSIDE Netflix 宣布將再次調漲訂閱收費價格，包含美國、英國及歐洲市場的基本與高級訂閱方案都會有微幅調漲。此次調整主要是因應內容製作成本等需求。Netflix 強調當前訂閱方案價定價仍比其他串流影音服務具競爭力。
| VIEW MORE »
|  | ### INSIDE 台積電宣布不進駐龍科三期後，各方爭取讓台積電在台設廠。經濟部長王美花表示，將協尋未來用地，她強調台積電的先進製程和產能一定會留在台灣。
| VIEW MORE »
### INSIDE 由於歐洲對下一代 5G 設備的投資減少，公司預計在新的成本削減計畫中，裁員 1.4 萬人
| VIEW MORE »
|  | ### INSIDE TOYOTA 和 Lexus 2025 起開始在「部分車款」採用 NACS，還會為現有或這兩年內即將推出的電動車提供轉接器，讓他們支援北美的特斯拉超級充電站。
| VIEW MORE »